@@ -2,7 +2,7 @@ from datetime import datetime
 from typing import Dict, List, Optional, Union
 
 
-TypeOp = Dict[str, Union[str, bool, int, List['TypeOp'], 'TypeOp']]
+TypeOp = Dict[str, Union[str, bool, int, List["TypeOp"], "TypeOp"]]
 
 
 class JsonFilterOperator:
@@ -11,11 +11,12 @@ class JsonFilterOperator:
 
     基本的にはこのオブジェクト1つで検索条件を表現するが、入子的に複数の検索条件が設定されることがある。
     """
+
     def __init__(self, json_: TypeOp):
         self.json: TypeOp = json_
 
     @staticmethod
-    def unit(term: 'JsonFilterTerm') -> 'JsonFilterOperator':
+    def unit(term: "JsonFilterTerm") -> "JsonFilterOperator":
         """
         単一の絞り込み要素のみで絞り込むことを明示的に宣言する。
 
@@ -29,40 +30,29 @@ class JsonFilterOperator:
         return JsonFilterOperator(term.json)
 
     @staticmethod
-    def not_(
-            term: 'JsonFilterOperator'
-    ) -> 'JsonFilterOperator':
+    def not_(term: "JsonFilterOperator") -> "JsonFilterOperator":
         """
         与えられた絞り込み要素の論理否定を表現する絞り込み条件。
 
         :param term: 否定したい絞り込み要素
         :return: 絞り込み条件オブジェクト
         """
-        json_: TypeOp = {
-            "type": "not",
-            "filter": term.json
-        }
+        json_: TypeOp = {"type": "not", "filter": term.json}
         return JsonFilterOperator(json_)
 
     @staticmethod
     def _binary(
-            op_name: str,
-            left: 'JsonFilterOperator',
-            right: 'JsonFilterOperator'
-    ) -> 'JsonFilterOperator':
-        json_: TypeOp = {
-            "type": op_name,
-            "filters": []
-        }
+        op_name: str, left: "JsonFilterOperator", right: "JsonFilterOperator"
+    ) -> "JsonFilterOperator":
+        json_: TypeOp = {"type": op_name, "filters": []}
         json_["filters"].append(left.json)
         json_["filters"].append(right.json)
         return JsonFilterOperator(json_)
 
     @staticmethod
     def or_(
-            left: 'JsonFilterOperator',
-            right: 'JsonFilterOperator'
-    ) -> 'JsonFilterOperator':
+        left: "JsonFilterOperator", right: "JsonFilterOperator"
+    ) -> "JsonFilterOperator":
         """
         2つの絞り込み要素のどちらかが正しいことを表す絞り込み条件。
 
@@ -74,9 +64,8 @@ class JsonFilterOperator:
 
     @staticmethod
     def and_(
-            left: 'JsonFilterOperator',
-            right: 'JsonFilterOperator'
-    ) -> 'JsonFilterOperator':
+        left: "JsonFilterOperator", right: "JsonFilterOperator"
+    ) -> "JsonFilterOperator":
         """
         2つの絞り込み要素の両方が正しいことを表す絞り込み条件。
 
@@ -95,16 +84,17 @@ class JsonFilterTerm(JsonFilterOperator):
 
     TODO: equal 絞り込みを実装する。
     """
+
     def __init__(self):
         super().__init__({})
 
     @staticmethod
     def set_range_view(
-            from_: Optional[int] = None,
-            to_: Optional[int] = None,
-            include_lower: bool = True,
-            include_upper: bool = True,
-    ) -> 'JsonFilterTerm':
+        from_: Optional[int] = None,
+        to_: Optional[int] = None,
+        include_lower: bool = True,
+        include_upper: bool = True,
+    ) -> "JsonFilterTerm":
         """
         再生回数が与えられた範囲内かを調べる検索要素。
 
@@ -119,7 +109,7 @@ class JsonFilterTerm(JsonFilterOperator):
             raise Exception("上限も下限も指定されていません")
         json_: Dict[str, Union[str, bool, int]] = {
             "type": "range",
-            "field": "viewCounter"
+            "field": "viewCounter",
         }
         if from_ is not None:
             json_["from"] = from_
@@ -134,11 +124,11 @@ class JsonFilterTerm(JsonFilterOperator):
 
     @staticmethod
     def set_range_time(
-            from_: Optional[datetime] = None,
-            to_: Optional[datetime] = None,
-            include_lower: bool = True,
-            include_upper: bool = True,
-    ) -> 'JsonFilterTerm':
+        from_: Optional[datetime] = None,
+        to_: Optional[datetime] = None,
+        include_lower: bool = True,
+        include_upper: bool = True,
+    ) -> "JsonFilterTerm":
         """
         投稿時刻が与えられた範囲内かを調べる検索要素。
 
@@ -151,14 +141,11 @@ class JsonFilterTerm(JsonFilterOperator):
         term: JsonFilterTerm = JsonFilterTerm()
         if from_ is None and to_ is None:
             raise Exception("開始時刻も終了時刻も指定されていません")
-        json_: Dict[str, Union[str, bool]] = {
-            "type": "range",
-            "field": "startTime"
-        }
+        json_: Dict[str, Union[str, bool]] = {"type": "range", "field": "startTime"}
         if from_ is not None:
-            json_["from"] = from_.strftime('%Y-%m-%dT%H:%M:%S+09:00')
+            json_["from"] = from_.strftime("%Y-%m-%dT%H:%M:%S+09:00")
         if to_ is not None:
-            json_["to"] = to_.strftime('%Y-%m-%dT%H:%M:%S+09:00')
+            json_["to"] = to_.strftime("%Y-%m-%dT%H:%M:%S+09:00")
         if include_lower:
             json_["include_lower"] = include_lower
         if include_upper:
